#!/bin/sh
#
# This is a script for re-formatting the MADIS output
# by variable into the file format needed for the MET
# ascii2nc program.
# This utility is called by the met-ascii2nc.sh script when
# reformatting data for use by ascii2nc.
#

if [ "$#" -ne 2 ] ; then
  echo "Usage: ascii2nc_reformat.sh input_filename land/maritime"
  exit 1
fi

file=$1
type=$2  # set to "land" or "maritime"

if [ -s $file ] ; then

cat $file | awk '{
if (NR > 5)
{

obstype="'"$type"'"
if (obstype == "land")     {mesgtype="ADPSFC"}
if (obstype == "maritime") {mesgtype="SFCSHP"}
level=-9999
var=$1
stid=$2
elev=$3
lat=$4
lon=$5
vtime=$8"00"
obs=$10

if (var == "V-P")
{
gribcode=1
hght=elev+2
}
if (var == "V-SLP")
{
gribcode=2
hght=elev+2
}
if (var == "V-T")
{
gribcode=11
hght=elev+2
}
if (var == "V-TD")
{
gribcode=17
hght=elev+2
}
if (var == "V-DD")
{
gribcode=31
hght=elev+10
}
if (var == "V-FF")
{
gribcode=32
hght=elev+10
}
if (var == "V-U")
{
gribcode=33
hght=elev+10
}
if (var == "V-V")
{
gribcode=34
hght=elev+10
}
if (var == "V-Q")
{
gribcode=51
hght=elev+2
}
if (var == "V-RH")
{
gribcode=52
hght=elev+2
}

printf ("%6s %8s %15s %7.2f %7.2f %7.2f %3d %5d %7.2f %9.2f \n",mesgtype,stid,vtime,lat,lon,elev,gribcode,level,hght,obs)

}

}'

else
  echo "The file \"$file\" does not exist!"
fi

exit
